//
//  AddPartViewController.m
//  PLS Mobile
//
//  Created by Daniel Workman on 30/04/2013.
//  Copyright (c) 2013 Daniel Workman. All rights reserved.
//

#import "AddPartViewController.h"
#import "ASIHTTPRequest.h"
#import "ASIFormDataRequest.h"
#import "SBJson.h"
#import "MBProgressHUD.h"
#import "Part.h"

@interface AddPartViewController ()

@end

@implementation AddPartViewController

@synthesize quantityField;
@synthesize partIdField;
@synthesize addButton;
@synthesize qtyStepper;

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (IBAction)partIdChanged:(id)sender {
    self.navigationItem.rightBarButtonItem = [partIdField.text length] > 0 ? addButton : nil;
}

- (void)viewDidLoad
{
    [super viewDidLoad];

    // Hide our Add button as there will not yet be a Part ID
    self.navigationItem.rightBarButtonItem = nil;
}

- (IBAction)stepperChanged:(id)sender {
    int quantity = [qtyStepper value];
    quantityField.text = [NSString stringWithFormat:@"%d", quantity];
}

- (IBAction)quantityChanged:(id)sender {
    NSInteger qty = [quantityField.text integerValue];

    if (qty <= 1) {
        qty = 1;
    }

    [qtyStepper setValue:qty];
    quantityField.text = [NSString stringWithFormat:@"%d", qty];
}

- (IBAction)quantityChanging:(id)sender {
    NSInteger qty = [quantityField.text integerValue];

    if (qty > 100) {
        qty = 100;
        quantityField.text = [NSString stringWithFormat:@"%d", qty];
    }

    [qtyStepper setValue:qty];
}

- (IBAction)scanBtnPressed:(id)sender
{
    ZBarReaderViewController *reader = [ZBarReaderViewController new];
    reader.readerDelegate = self;
    
    // Disable all other symbologies
    [reader.scanner setSymbology: 0
                          config: ZBAR_CFG_ENABLE
                              to: 0];
    
    // Enable Code 128 only
    [reader.scanner setSymbology: ZBAR_CODE128
                          config: ZBAR_CFG_ENABLE
                              to: 1];

    reader.readerView.zoom = 1.0;

    [self presentViewController:reader animated:YES completion:nil];
}

- (void) imagePickerController: (UIImagePickerController*) reader
 didFinishPickingMediaWithInfo: (NSDictionary*) info
{
    [reader dismissViewControllerAnimated:YES completion:NO];

    id<NSFastEnumeration> results = [info objectForKey: ZBarReaderControllerResults];

    ZBarSymbol *symbol = nil;
    for (symbol in results) {
        NSInteger partId = [[symbol.data stringByTrimmingCharactersInSet:[NSCharacterSet characterSetWithCharactersInString:@"!A"]] integerValue];

        partIdField.text = [NSString stringWithFormat:@"%d", partId];

        // Turn on the add button as we have scanned a code
        self.navigationItem.rightBarButtonItem = addButton;
    
        // We don't care if the scanner finds multiple codes as the engineer should only scan one code
        break;
    }
}

- (IBAction)addBtnPressed:(id)sender
{
    [quantityField resignFirstResponder];
    [partIdField resignFirstResponder];
    
    // Start request
    NSString *urlString = [[NSUserDefaults standardUserDefaults] stringForKey:@"database_url"];
    ASIFormDataRequest *request = [ASIFormDataRequest requestWithURL:[NSURL URLWithString:urlString]];
    [request setPostValue:@"add_job_part" forKey:@"request"];
    [request setPostValue:[NSString stringWithFormat:@"%d", self.sender.sender.jobId] forKey:@"job_id"];
    [request setPostValue:partIdField.text forKey:@"part_id"];
    [request setPostValue:quantityField.text forKey:@"quantity"];
    [request setDelegate:self];
    [request startAsynchronous];
    
    MBProgressHUD *hud = [MBProgressHUD showHUDAddedTo:self.view animated:YES];
    hud.labelText = @"Adding part...";
}

- (void)requestFinished:(ASIHTTPRequest *)request
{
    [MBProgressHUD hideHUDForView:self.view animated:YES];
    
    if (request.responseStatusCode == 200) {
        NSString *responseString = [request responseString];
        NSDictionary *responseDict = [responseString JSONValue];
        
        Part *part = [[Part alloc] init];
        part.partId = [[responseDict objectForKey:@"id"] integerValue];
        part.make = [responseDict objectForKey:@"make"];
        part.model = [responseDict objectForKey:@"model"];
        part.quantity = [quantityField.text integerValue];
        [self.sender.sender.parts addObject:part];

        [self.navigationController popViewControllerAnimated:YES];
    } else {
        ALERT(@"Request Failed", request.responseStatusMessage);
    }
}

- (void)requestFailed:(ASIHTTPRequest *)request
{
    [MBProgressHUD hideHUDForView:self.view animated:YES];
    ALERT(@"Request Failed", [[request error] localizedDescription]);
}


- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

@end
