//
//  SiteDetailsViewController.m
//  PLS Mobile
//
//  Created by Daniel Workman on 28/04/2013.
//  Copyright (c) 2013 Daniel Workman. All rights reserved.
//

#import "SiteDetailsViewController.h"
#import "ASIHTTPRequest.h"
#import "ASIFormDataRequest.h"
#import "SBJson.h"
#import "MBProgressHUD.h"
#import <CoreLocation/CLGeocoder.h>

@interface SiteDetailsViewController ()

@end

@implementation SiteDetailsViewController

@synthesize siteId;

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)reverseGeocode:(NSString*)address
{
    CLGeocoder *geocoder = [[CLGeocoder alloc] init];
    [geocoder geocodeAddressString:address
                 completionHandler:^(NSArray* placemarks, NSError* error) {
                     if (placemarks && placemarks.count > 0) {
                         CLPlacemark *topResult = [placemarks objectAtIndex:0];
                         MKPlacemark *placemark = [[MKPlacemark alloc] initWithPlacemark:topResult];
                         
                         MKCoordinateRegion region = self.mapView.region;
                         region.center = placemark.region.center;
                         
                         // Show zoom animation starting from above destination not from the US as is the default
                         [self.mapView setRegion:region animated:NO];
                         region.span.longitudeDelta /= 2500.0;
                         region.span.latitudeDelta /= 2500.0;
                         [self.mapView setRegion:region animated:YES];
                         
                         [self.mapView addAnnotation:placemark];
                     }
                 }
     ];
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    if (self.siteId <= 0) {
        ALERT(@"Error", @"Invalid Site ID");
        return;
    }
    
    // Start request
    NSString *urlString = [[NSUserDefaults standardUserDefaults] stringForKey:@"database_url"];
    ASIFormDataRequest *request = [ASIFormDataRequest requestWithURL:[NSURL URLWithString:urlString]];
    [request setPostValue:@"site" forKey:@"request"];
    [request setPostValue:[NSString stringWithFormat:@"%d", self.siteId] forKey:@"site_id"];
    [request setDelegate:self];
    [request startAsynchronous];
    
    MBProgressHUD *hud = [MBProgressHUD showHUDAddedTo:self.view animated:YES];
    hud.labelText = @"Loading site...";

    // Uncomment the following line to preserve selection between presentations.
    // self.clearsSelectionOnViewWillAppear = NO;
 
    // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
    // self.navigationItem.rightBarButtonItem = self.editButtonItem;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)requestFinished:(ASIHTTPRequest *)request
{
    [MBProgressHUD hideHUDForView:self.view animated:YES];
    
    if (request.responseStatusCode == 200) {
        NSString *responseString = [request responseString];
        NSDictionary *responseDict = [responseString JSONValue];

        //NSString* site = [responseDict objectForKey:@"name"];
        NSString* line1 = [responseDict objectForKey:@"addressLine1"];
        NSString* line2 = [responseDict objectForKey:@"addressLine2"];
        NSString* town = [responseDict objectForKey:@"town"];
        NSString* county = [responseDict objectForKey:@"county"];
        NSString* postcode = [responseDict objectForKey:@"postcode"];
        
        NSMutableString *address = [NSMutableString stringWithCapacity:100];
        if ([line1 length] > 0) {
            [address appendString:line1];
            [address appendString:@"\r\n"];
        }
        if ([line2 length] > 0) {
            [address appendString:line2];
            [address appendString:@"\r\n"];
        }
        if ([town length] > 0) {
            [address appendString:town];
            [address appendString:@"\r\n"];
        }
        if ([county length] > 0) {
            [address appendString:county];
            [address appendString:@"\r\n"];
        }
        [address appendString:postcode];
        
        self.addressCell.text = address;
        [self reverseGeocode:address];

        self.phoneCell.textLabel.text = [responseDict objectForKey:@"phone"];
        
        [self.tableView reloadData];

    } else {
        ALERT(@"", request.responseStatusMessage);
    }
}

- (void)requestFailed:(ASIHTTPRequest *)request
{
    [MBProgressHUD hideHUDForView:self.view animated:YES];
    ALERT(@"Request Failed", [[request error] localizedDescription]);
}

#pragma mark - Table view delegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    UITableViewCell *cell = [tableView cellForRowAtIndexPath:indexPath];
    
    // If the user has clicked on the phone number cell then prompt to place a call
    if ([cell.reuseIdentifier isEqualToString:@"PhoneCell"]) {
        
        NSString *noWhitespace = [cell.textLabel.text stringByReplacingOccurrencesOfString:@" " withString:@""];
        NSString *numberString = [NSString stringWithFormat:@"tel://%@",noWhitespace];
        [[UIApplication sharedApplication] openURL:[NSURL URLWithString:numberString]];
        
        [tableView deselectRowAtIndexPath:indexPath animated:YES];
    }
}

@end
